import { Balances, ControlClaim, EthereumAddress, HypernetLink, PublicIdentifier, PullPayment, PushPayment, Payment, PaymentId, MerchantUrl, Signature } from "@hypernetlabs/objects";
import { AcceptPaymentError, RouterChannelUnknownError, BlockchainUnavailableError, VectorError, LogicalError, BalancesUnavailableError, InsufficientBalanceError, MerchantValidationError, PersistenceError, MerchantConnectorError, ProxyError, InvalidPaymentError, InvalidParametersError, TransferResolutionError } from "@hypernetlabs/objects";
import { ParentProxy } from "@hypernetlabs/utils";
import { BigNumber } from "ethers";
import { Result, ResultAsync } from "neverthrow";
import { Subject } from "rxjs";
import IHypernetIFrameProxy from "../../interfaces/proxy/IHypernetIFrameProxy";
export default class HypernetIFrameProxy extends ParentProxy implements IHypernetIFrameProxy {
    protected coreInitialized: boolean;
    protected isInControl: boolean;
    protected waitInitializedPromise: Promise<void>;
    protected _handshakePromise: Promise<void> | null;
    constructor(element: HTMLElement | null, iframeUrl: string, iframeName: string);
    finalizePullPayment(_paymentId: PaymentId, _finalAmount: BigNumber): Promise<HypernetLink>;
    initialized(): Result<boolean, LogicalError>;
    waitInitialized(): ResultAsync<void, LogicalError>;
    inControl(): Result<boolean, LogicalError>;
    getEthereumAccounts(): ResultAsync<EthereumAddress[], BlockchainUnavailableError>;
    initialize(account: EthereumAddress): ResultAsync<void, LogicalError>;
    getPublicIdentifier(): ResultAsync<PublicIdentifier, ProxyError>;
    depositFunds(assetAddress: EthereumAddress, amount: BigNumber): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    withdrawFunds(assetAddress: EthereumAddress, amount: BigNumber, destinationAddress: EthereumAddress): ResultAsync<Balances, BalancesUnavailableError | BlockchainUnavailableError | VectorError | Error>;
    getBalances(): ResultAsync<Balances, BalancesUnavailableError>;
    getLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    getActiveLinks(): ResultAsync<HypernetLink[], RouterChannelUnknownError | VectorError | Error>;
    getLinkByCounterparty(_counterPartyAccount: PublicIdentifier): Promise<HypernetLink>;
    sendFunds(counterPartyAccount: PublicIdentifier, amount: string, expirationDate: number, requiredStake: string, paymentToken: EthereumAddress, merchantUrl: MerchantUrl): ResultAsync<Payment, RouterChannelUnknownError | VectorError | Error>;
    authorizeFunds(counterPartyAccount: PublicIdentifier, totalAuthorized: BigNumber, expirationDate: number, deltaAmount: string, deltaTime: number, requiredStake: BigNumber, paymentToken: EthereumAddress, merchantUrl: MerchantUrl): ResultAsync<Payment, RouterChannelUnknownError | VectorError | Error>;
    acceptOffers(paymentIds: PaymentId[]): ResultAsync<Result<Payment, AcceptPaymentError>[], InsufficientBalanceError | AcceptPaymentError>;
    pullFunds(paymentId: PaymentId, amount: BigNumber): ResultAsync<Payment, RouterChannelUnknownError | VectorError | Error>;
    initiateDispute(paymentId: PaymentId): ResultAsync<Payment, MerchantConnectorError | MerchantValidationError | RouterChannelUnknownError | VectorError | BlockchainUnavailableError | LogicalError | InvalidPaymentError | InvalidParametersError | TransferResolutionError>;
    mintTestToken(amount: BigNumber): ResultAsync<void, BlockchainUnavailableError>;
    authorizeMerchant(merchantUrl: MerchantUrl): ResultAsync<void, MerchantValidationError>;
    getAuthorizedMerchants(): ResultAsync<Map<MerchantUrl, Signature>, PersistenceError>;
    closeMerchantIFrame(merchantUrl: MerchantUrl): ResultAsync<void, MerchantConnectorError>;
    displayMerchantIFrame(merchantUrl: MerchantUrl): ResultAsync<void, MerchantConnectorError>;
    providePrivateCredentials(privateKey: string | null, mnemonic: string | null): ResultAsync<void, InvalidParametersError>;
    /**
     * Observables for seeing what's going on
     */
    onControlClaimed: Subject<ControlClaim>;
    onControlYielded: Subject<ControlClaim>;
    onPushPaymentSent: Subject<PushPayment>;
    onPullPaymentSent: Subject<PullPayment>;
    onPushPaymentUpdated: Subject<PushPayment>;
    onPullPaymentUpdated: Subject<PullPayment>;
    onPushPaymentReceived: Subject<PushPayment>;
    onPullPaymentReceived: Subject<PullPayment>;
    onPushPaymentDelayed: Subject<PushPayment>;
    onPullPaymentDelayed: Subject<PullPayment>;
    onBalancesChanged: Subject<Balances>;
    onMerchantAuthorized: Subject<MerchantUrl>;
    onAuthorizedMerchantUpdated: Subject<MerchantUrl>;
    onAuthorizedMerchantActivationFailed: Subject<MerchantUrl>;
    onMerchantIFrameDisplayRequested: Subject<MerchantUrl>;
    onMerchantIFrameCloseRequested: Subject<MerchantUrl>;
    onInitializationRequired: Subject<void>;
    onPrivateCredentialsRequested: Subject<void>;
}
//# sourceMappingURL=HypernetIFrameProxy.d.ts.map